{% extends "core/base.html" %}


{% block content %}

          <h2 class="message-box">Investments</h2>
          <div class="table-responsive">
            <table class="table table-striped">
              <thead>
                <tr>
                  <th>Investment</th>
                  <th>KPI</th>
                  <th>Value</th>
                </tr>
              </thead>
              <tbody>
                <tr>
                  <td>1,001</td>
                  <td>1,234</td>
                  <td>1,299</td>
                </tr>
              </tbody>
            </table>
          </div>


{% endblock %}
